package com.fireworksdk.bridge.flutter.handler

import android.view.SurfaceView
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import androidx.fragment.app.FragmentActivity
import com.fireworksdk.bridge.components.storyblock.StoryBlockFrameLayout
import com.fireworksdk.bridge.flutter.models.FWStoryBlockCallMethod
import com.fireworksdk.bridge.utils.FWCommonUtil
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import java.lang.reflect.Method


class FWStoryBlockHandler(
  private val activity: FragmentActivity,
  private val storyBlockFrameLayout: StoryBlockFrameLayout,
) : MethodChannel.MethodCallHandler {

  private var handleResult: MethodChannel.Result? = null

  override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
    handleResult = result

    when (call.method) {
      FWStoryBlockCallMethod.Play.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.play()
        result.success(null)
      }
      FWStoryBlockCallMethod.Pause.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.pause()
        result.success(null)
      }
      FWStoryBlockCallMethod.ToggleFullScreen.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.toggleFullScreen()
        result.success(null)
      }

      FWStoryBlockCallMethod.SetMarginRight.rawValue -> {
        val right: Double = call.arguments as Double
        val layoutParams = FrameLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.MATCH_PARENT
        )
        layoutParams.setMargins(0, 0, FWCommonUtil.dpToPx(right.toFloat(), activity), 0)
        storyBlockFrameLayout.storyBlockFragment?.setStoryBlockLayoutParams(layoutParams)
        result.success(null)
      }

      FWStoryBlockCallMethod.SetStoryBlockConfiguration.rawValue -> {
        result.success(null)
      }

      FWStoryBlockCallMethod.Show.rawValue -> {
        val ivsPlayerViewList = mutableListOf<ViewGroup>()
        searchVisibleIvsPlayerView(storyBlockFrameLayout.storyBlockFragment?.getStoryBlockView(), ivsPlayerViewList)
        showIvsPlayerSurfaceView(ivsPlayerViewList)
        result.success(null)
      }

      FWStoryBlockCallMethod.Hide.rawValue -> {
        val ivsPlayerViewList = mutableListOf<ViewGroup>()
        searchVisibleIvsPlayerView(storyBlockFrameLayout.storyBlockFragment?.getStoryBlockView(), ivsPlayerViewList)
        hideIvsPlayerSurfaceView(ivsPlayerViewList)
        result.success(null)
      }

      else -> {
        result.notImplemented()
      }
    }
  }

  private fun searchVisibleIvsPlayerView(viewGroup: ViewGroup?, list: MutableList<ViewGroup>) {
    viewGroup ?: return

    val childCount = viewGroup.childCount
    for (index in 0 until childCount) {
      val view = viewGroup.getChildAt(index)
      if (view is ViewGroup) {
        val className = view.javaClass.name
        if (className.equals("com.amazonaws.ivs.player.PlayerView")) {
          list.add(view)
        } else {
          searchVisibleIvsPlayerView(view, list)
        }
      }
    }
  }

  private fun hideIvsPlayerSurfaceView(list: List<ViewGroup>?) {
    list ?: return
    for (viewGroup in list) {
      val childCount = viewGroup.childCount
      for (index in 0 until childCount) {
        val view = viewGroup.getChildAt(index)
        if (view is SurfaceView) {
          view.visibility = View.INVISIBLE
        }
      }
    }
  }

  private fun showIvsPlayerSurfaceView(list: List<ViewGroup>?) {
    list ?: return
    for (viewGroup in list) {
      val childCount = viewGroup.childCount
      for (index in 0 until childCount) {
        val view = viewGroup.getChildAt(index)
        if (view is SurfaceView) {
          view.visibility = View.VISIBLE
        }
      }
    }
  }

  private fun hideStoryBlockFragment() {
    storyBlockFrameLayout.storyBlockFragment?.let {
      val fm = activity.supportFragmentManager
      fm.beginTransaction().hide(it).commit()
    }
  }

  private fun showStoryBlockFragment() {
    storyBlockFrameLayout.storyBlockFragment?.let {
      val fm = activity.supportFragmentManager
      fm.beginTransaction().show(it).commit()
    }
  }

  private fun pauseIvsPlayerView(list: List<ViewGroup>?) {
    list ?: return
    for (view in list) {
      val getPlayerMethod: Method = view.javaClass.getDeclaredMethod("getPlayer")
      val player = getPlayerMethod.invoke(view)
      val pauseMethod: Method = player.javaClass.getDeclaredMethod("pause")
      pauseMethod.invoke(player)
    }
  }

  private fun playIvsPlayerView(list: List<ViewGroup>?) {
    list ?: return
    for (view in list) {
      val getPlayerMethod: Method = view.javaClass.getDeclaredMethod("getPlayer")
      val player = getPlayerMethod.invoke(view)
      val playMethod: Method = player.javaClass.getDeclaredMethod("play")
      playMethod.invoke(player)
    }
  }
}