package com.fireworksdk.bridge.flutter.handler

import android.view.ViewGroup
import android.widget.FrameLayout
import com.fireworksdk.bridge.components.videofeed.FWVideoFeed
import com.fireworksdk.bridge.flutter.models.FWVideoFeedCallMethod
import com.fireworksdk.bridge.flutter.platformview.FWVideoFeedPlatformView
import com.fireworksdk.bridge.utils.FWCommonUtil
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.Result

class FWVideoFeedHandler(
  videoFeedPlatformView: FWVideoFeedPlatformView,
) : MethodChannel.MethodCallHandler {

  private val videoFeed: FWVideoFeed = videoFeedPlatformView.videoFeed

  private var handleResult: Result? = null

  override fun onMethodCall(call: MethodCall, result: Result) {
    handleResult = result

    when (call.method) {
      FWVideoFeedCallMethod.SetVideoFeedConfiguration.rawValue -> {
        result.success(null)
      }

      FWVideoFeedCallMethod.SetVideoPlayerConfiguration.rawValue -> {
        result.success(null)
      }

      FWVideoFeedCallMethod.Refresh.rawValue -> {
        videoFeed.refresh()
        result.success(null)
      }

      FWVideoFeedCallMethod.SetMarginRight.rawValue -> {
        val right: Double = call.arguments as Double
        val layoutParams = FrameLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.MATCH_PARENT
        )
        layoutParams.setMargins(0, 0, FWCommonUtil.dpToPx(right.toFloat(), videoFeed.context), 0)
        videoFeed.setVideoFeedLayoutParams(layoutParams)
        result.success(null)
      }

      else -> {
        result.notImplemented()
      }
    }
  }
}