package com.fireworksdk.bridge.models

import java.lang.ref.WeakReference
import kotlin.properties.ReadWriteProperty
import kotlin.reflect.KProperty

fun <V> weakProperty(defaultValue: V? = null) = WeakProperty(defaultValue)

class WeakProperty<V>(defaultValue: V? = null) : ReadWriteProperty<Any?, V?> {
    private var reference: WeakReference<V>? = WeakReference(defaultValue)

    override fun getValue(thisRef: Any?, property: KProperty<*>): V? {
        return reference?.get()
    }

    override fun setValue(thisRef: Any?, property: KProperty<*>, value: V?) {
        reference = if (value != null) WeakReference(value) else null
    }
}
