import 'video_player_complete_action.dart';
import 'video_player_cta_delay.dart';
import 'video_player_cta_width.dart';

class StoryBlockConfiguration {
  /// Behavior occurring after video is complete.
  /// On iOS, the property only applies to full-screen story block but not to compact story block.
  /// On Android, the property applies to full-screen and compact story block.
  VideoPlayerCompleteAction? videoCompleteAction;

  /// Indicates if the video player shows share button.
  bool? showShareButton;

  /// Indicates if the video player shows playback button.
  /// Only supported on Android.
  bool? showPlaybackButton;

  /// Indicates if Firework branding should be showed or not.
  bool? showBranding;

  /// Specifies the delay before showing the CTA.
  VideoPlayerCTADelay? ctaDelay;

  /// Specifies the delay before the highlight animation occurs.
  VideoPlayerCTADelay? ctaHighlightDelay;

  /// The share base URL of the video.
  String? shareBaseURL;

  /// Specifies the desired width for the Video Player CTA button.
  VideoPlayerCTAWidth? ctaWidth;

  /// Specifies if the video detail title should be showed or not.
  /// Only supported on iOS.
  bool? showVideoDetailTitle;

  StoryBlockConfiguration({
    this.videoCompleteAction,
    this.showShareButton,
    this.showPlaybackButton,
    this.showBranding,
    this.ctaDelay,
    this.ctaHighlightDelay,
    this.shareBaseURL,
    this.ctaWidth,
    this.showVideoDetailTitle,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is StoryBlockConfiguration) {
      return videoCompleteAction == other.videoCompleteAction &&
          showShareButton == other.showShareButton &&
          showPlaybackButton == other.showPlaybackButton &&
          showBranding == other.showBranding &&
          ctaDelay == other.ctaDelay &&
          ctaHighlightDelay == other.ctaHighlightDelay &&
          shareBaseURL == other.shareBaseURL &&
          ctaWidth == other.ctaWidth &&
          showVideoDetailTitle == other.showVideoDetailTitle;
    }

    return false;
  }

  @override
  int get hashCode =>
      videoCompleteAction.hashCode ^
      showShareButton.hashCode ^
      showPlaybackButton.hashCode ^
      showBranding.hashCode ^
      ctaDelay.hashCode ^
      ctaHighlightDelay.hashCode ^
      shareBaseURL.hashCode ^
      ctaWidth.hashCode ^
      showVideoDetailTitle.hashCode;

  StoryBlockConfiguration deepCopy() => StoryBlockConfiguration(
        videoCompleteAction: videoCompleteAction,
        showShareButton: showShareButton,
        showPlaybackButton: showPlaybackButton,
        showBranding: showBranding,
        ctaDelay: ctaDelay?.deepCopy(),
        ctaHighlightDelay: ctaHighlightDelay?.deepCopy(),
        shareBaseURL: shareBaseURL,
        ctaWidth: ctaWidth,
        showVideoDetailTitle: showVideoDetailTitle,
      );
}
