class VideoPlayerSize {
  double width;
  double height;
  VideoPlayerSize({
    required this.width,
    required this.height,
  });
}

class VideoPlaybackDetails {
  /// A unique identifier of the video.
  String videoId;

  /// The total duration of the video.
  double? duration;

  /// The caption for the video.
  String? caption;

  /// Video badge type.
  String? badge;

  /// The size of the player.
  VideoPlayerSize? playerSize;

  /// Indicates if the video is associated with a call-to-action (CTA).
  bool? hasCTA;

  /// The amount of time the video was playing at the time of the event.
  double? progress;

  /// The type of the CTA button clicked: "buy" "download" "view" "book".
  String? ctaActionType;

  /// The url of the CTA button clicked.
  String? ctaActionURL;

  /// The associated feed ID
  String? feedId;

  VideoPlaybackDetails(
      {required this.videoId,
      this.duration,
      this.caption,
      this.badge,
      this.playerSize,
      this.hasCTA,
      this.progress,
      this.ctaActionType,
      this.ctaActionURL,
      this.feedId});
}

enum VideoPlaybackEventName {
  /// When video is shown to the user.
  impression("fw:video:impression"),

  /// Video started.
  start("fw:video:start"),

  /// Video paused.
  pause("fw:video:pause"),

  /// Video resume.
  resume("fw:video:resume"),

  /// Video reached 25%.
  firstQuartile("fw:video:first-quartile"),

  /// Video reached 50%.
  midpoint("fw:video:midpoint"),

  /// Video reached 75%.
  thirdQuartile("fw:video:third-quartile"),

  /// Video reached 100%.
  complete("fw:video:complete"),

  /// When ad video finishes playing.
  adStart("fw:video:adStart"),

  /// When ad video finishes playing.
  adEnd("fw:video:ad-end"),

  /// When a visitor clicks on CTA button (if available).
  clickCTA("fw:video:click-cta"),

  /// When user clicks on "Share" button.
  clickShare("fw:video:click-share");

  final String rawName;
  const VideoPlaybackEventName(this.rawName);
}
