import 'button_info.dart';

class VideoPlayerButtonConfiguration {
  /// Specifies the video detail button info.
  /// Image will be drawn in a 40pt x 40pt frame.
  /// Only supported on iOS.
  final ButtonInfo? videoDetailButton;

  /// Specifies the close button info.
  /// Image will be drawn in a 40pt x 40pt frame.
  /// Only supported on iOS.
  final ButtonInfo? closeButton;

  /// Specifies the mute button info.
  /// Image will be drawn in a 40pt x 40pt frame.
  /// Only supported on iOS.
  final ButtonInfo? muteButton;

  /// Specifies the unmute button info.
  /// Image will be drawn in a 40pt x 40pt frame.
  /// Only supported on iOS.
  final ButtonInfo? unmuteButton;

  /// Specifies the play info.
  /// Image will be drawn at the center of the player view.
  /// Only supported on iOS.
  final ButtonInfo? playButton;

  /// Specifies the pause info.
  /// Image will be drawn at the center of the player view.
  /// Only supported on iOS.
  final ButtonInfo? pauseButton;

  VideoPlayerButtonConfiguration({
    this.videoDetailButton,
    this.closeButton,
    this.muteButton,
    this.unmuteButton,
    this.playButton,
    this.pauseButton,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerButtonConfiguration) {
      return videoDetailButton == other.videoDetailButton &&
          closeButton == other.closeButton &&
          muteButton == other.muteButton &&
          unmuteButton == other.unmuteButton &&
          playButton == other.playButton &&
          pauseButton == other.pauseButton;
    }

    return false;
  }

  @override
  int get hashCode =>
      videoDetailButton.hashCode ^
      closeButton.hashCode ^
      muteButton.hashCode ^
      unmuteButton.hashCode ^
      playButton.hashCode ^
      pauseButton.hashCode;

  VideoPlayerButtonConfiguration deepCopy() => VideoPlayerButtonConfiguration(
        videoDetailButton: videoDetailButton,
        closeButton: closeButton,
        muteButton: muteButton,
        unmuteButton: unmuteButton,
        playButton: playButton,
        pauseButton: pauseButton,
      );
}
