import 'package:fw_flutter_sdk/src/models/video_player_button_configuration.dart';

import 'video_player_complete_action.dart';
import 'video_player_cta_delay.dart';
import 'video_player_cta_style.dart';
import 'video_player_cta_width.dart';
import 'video_player_style.dart';

class VideoPlayerConfiguration {
  /// Sets the proportion of the video player to its container.
  /// Defaults to full.
  VideoPlayerStyle? playerStyle;

  /// Behavior occurring after video is complete.
  /// Defaults to advanceToNext.
  VideoPlayerCompleteAction? videoCompleteAction;

  /// Indicates if the video player shows share button.
  /// Defaults to true.
  bool? showShareButton;

  /// The style of CTA button style. Only supported on iOS.
  VideoPlayerCTAStyle? ctaButtonStyle;

  /// Indicates if the video player shows playback button.
  /// Defaults to false on iOS. Default to true on Android.
  bool? showPlaybackButton;

  /// Indicates if the video player shows mute button.
  /// Defaults to true.
  bool? showMuteButton;

  /// Indicates if Firework branding should be showed or not.
  /// Defaults to true.
  bool? showBranding;

  /// Specifies the delay before showing the CTA.
  /// Defaults to { type: constant, value: 3 }.
  VideoPlayerCTADelay? ctaDelay;

  /// Specifies the delay before the highlight animation occurs.
  /// Defaults to { type: constant, value: 2 }.
  VideoPlayerCTADelay? ctaHighlightDelay;

  /// The share base URL of the video.
  String? shareBaseURL;

  /// Specifies the desired width for the Video Player CTA button.
  /// Defaults to fullWidth.
  VideoPlayerCTAWidth? ctaWidth;

  /// The host app could use this property to customize the button images of the video player.
  /// Only supported on iOS.
  VideoPlayerButtonConfiguration? buttonConfiguration;

  /// Specifies if the video detail title should be showed or not.
  /// Only supported on iOS.
  bool? showVideoDetailTitle;

  VideoPlayerConfiguration({
    this.playerStyle,
    this.videoCompleteAction,
    this.showShareButton,
    this.ctaButtonStyle,
    this.showPlaybackButton,
    this.showMuteButton,
    this.showBranding,
    this.ctaDelay,
    this.ctaHighlightDelay,
    this.shareBaseURL,
    this.ctaWidth,
    this.buttonConfiguration,
    this.showVideoDetailTitle,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerConfiguration) {
      return playerStyle == other.playerStyle &&
          videoCompleteAction == other.videoCompleteAction &&
          showShareButton == other.showShareButton &&
          ctaButtonStyle == other.ctaButtonStyle &&
          showPlaybackButton == other.showPlaybackButton &&
          showMuteButton == other.showMuteButton &&
          showBranding == other.showBranding &&
          ctaDelay == other.ctaDelay &&
          ctaHighlightDelay == other.ctaHighlightDelay &&
          shareBaseURL == other.shareBaseURL &&
          ctaWidth == other.ctaWidth &&
          buttonConfiguration == other.buttonConfiguration &&
          showVideoDetailTitle == other.showVideoDetailTitle;
    }

    return false;
  }

  @override
  int get hashCode =>
      playerStyle.hashCode ^
      videoCompleteAction.hashCode ^
      showShareButton.hashCode ^
      ctaButtonStyle.hashCode ^
      showPlaybackButton.hashCode ^
      showMuteButton.hashCode ^
      showBranding.hashCode ^
      ctaDelay.hashCode ^
      ctaHighlightDelay.hashCode ^
      shareBaseURL.hashCode ^
      ctaWidth.hashCode ^
      buttonConfiguration.hashCode ^
      showVideoDetailTitle.hashCode;

  VideoPlayerConfiguration deepCopy() => VideoPlayerConfiguration(
        playerStyle: playerStyle,
        videoCompleteAction: videoCompleteAction,
        showShareButton: showShareButton,
        ctaButtonStyle: ctaButtonStyle?.deepCopy(),
        showPlaybackButton: showPlaybackButton,
        showMuteButton: showMuteButton,
        showBranding: showBranding,
        ctaDelay: ctaDelay?.deepCopy(),
        ctaHighlightDelay: ctaHighlightDelay?.deepCopy(),
        shareBaseURL: shareBaseURL,
        ctaWidth: ctaWidth,
        buttonConfiguration: buttonConfiguration,
        showVideoDetailTitle: showVideoDetailTitle,
      );
}
