import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/story_block_configuration.dart';
import 'package:fw_flutter_sdk/src/models/story_block_native_configuration.dart';
import 'package:fw_flutter_sdk/src/models/video_player_complete_action.dart';
import 'package:fw_flutter_sdk/src/models/video_player_cta_delay.dart';
import 'package:fw_flutter_sdk/src/models/video_player_cta_width.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/story_block_configuration_util.dart';

void main() {
  test('VideoPlayerConfigurationUtil toJson', () {
    final configuration = StoryBlockConfiguration(
      videoCompleteAction: VideoPlayerCompleteAction.advanceToNext,
      showShareButton: true,
      showPlaybackButton: true,
      showBranding: true,
      ctaDelay: VideoPlayerCTADelay(
        type: VideoPlayerCTADelayType.constant,
        value: 3,
      ),
      shareBaseURL: "test_share_url",
      ctaWidth: VideoPlayerCTAWidth.fullWidth,
    );
    final json = StoryBlockConfigurationUtil.toJson(configuration);
    expect(
        json["videoCompleteAction"], configuration.videoCompleteAction?.name);
    expect(json["showShareButton"], configuration.showShareButton);
    expect(json["showPlaybackButton"], configuration.showPlaybackButton);
    expect(json["showBranding"], configuration.showBranding);

    expect(json["ctaDelay"]["type"], configuration.ctaDelay?.type.name);
    expect(json["ctaDelay"]["value"], configuration.ctaDelay?.value);
    expect(json["shareBaseURL"], configuration.shareBaseURL);
    expect(json["ctaWidth"], configuration.ctaWidth?.name);
  });

  test('VideoPlayerConfigurationUtil toJson for StoryBlockNativeConfiguration',
      () {
    final configuration = StoryBlockNativeConfiguration(
      videoCompleteAction: VideoPlayerCompleteAction.advanceToNext,
      showShareButton: true,
      showPlaybackButton: true,
      showBranding: true,
      ctaDelay: VideoPlayerCTADelay(
        type: VideoPlayerCTADelayType.constant,
        value: 3,
      ),
      shareBaseURL: "test_share_url",
      ctaWidth: VideoPlayerCTAWidth.fullWidth,
      enablePictureInPicture: true,
    );
    final json = StoryBlockConfigurationUtil.toJson(configuration);
    expect(
        json["videoCompleteAction"], configuration.videoCompleteAction?.name);
    expect(json["showShareButton"], configuration.showShareButton);
    expect(json["showPlaybackButton"], configuration.showPlaybackButton);
    expect(json["showBranding"], configuration.showBranding);

    expect(json["ctaDelay"]["type"], configuration.ctaDelay?.type.name);
    expect(json["ctaDelay"]["value"], configuration.ctaDelay?.value);
    expect(json["shareBaseURL"], configuration.shareBaseURL);
    expect(json["ctaWidth"], configuration.ctaWidth?.name);
    expect(
        json["enablePictureInPicture"], configuration.enablePictureInPicture);
  });
}
