import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/android_font_info.dart';
import 'package:fw_flutter_sdk/src/models/ios_font_info.dart';
import 'package:fw_flutter_sdk/src/models/video_feed_configuration.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/video_feed_configuration_util.dart';

void main() {
  test('VideoFeedConfigurationUtil toJson', () {
    final configuration = VideoFeedConfiguration(
      backgroundColor: "#c0c0c0",
      cornerRadius: 30,
      title: VideoFeedTitleConfiguration(
        fontSize: 16,
        textColor: "#000000",
        hidden: false,
        numberOfLines: 1,
        iOSFontInfo: IOSFontInfo(
          fontName: "Helvetica",
          systemFontStyle: IOSSystemFontStyle.italic,
          systemFontWeight: IOSSystemFontWeight.heavy,
        ),
        androidFontInfo: AndroidFontInfo(
          isCustom: false,
          typefaceName: "DEFAULT_BOLD",
        ),
        gradientDrawable: GradientDrawable(
          orientation: GradientDrawableOrientation.rightLeft,
          colors: <String>[
            "#FF48C9B0",
            "#FFD98880",
            "#FFF4D03F",
          ],
        ),
      ),
      titlePosition: VideoFeedTitlePosition.nested,
      titlePadding: VideoFeedPadding(
        top: 2,
        right: 3,
        bottom: 5,
        left: 6,
      ),
      playIcon: VideoFeedPlayIconConfiguration(
        hidden: false,
        iconWidth: 10,
      ),
      showAdBadge: true,
      aspectRatio: 0.75,
      contentPadding: VideoFeedPadding(
        top: 10,
        right: 15,
        bottom: 11,
        left: 12,
      ),
      itemSpacing: 10,
      enableAutoplay: true,
      gridColumns: 3,
    );
    final json = VideoFeedConfigurationUtil.toJson(configuration);
    expect(json["backgroundColor"], configuration.backgroundColor);
    expect(json["cornerRadius"], configuration.cornerRadius);
    expect(json["title"] is Map<String, dynamic>, true);
    final titleJson = json["title"] as Map<String, dynamic>;
    expect(titleJson["fontSize"], configuration.title?.fontSize);
    expect(titleJson["textColor"], configuration.title?.textColor);
    expect(titleJson["hidden"], configuration.title?.hidden);
    expect(titleJson["numberOfLines"], configuration.title?.numberOfLines);
    expect(titleJson["iOSFontInfo"]["fontName"],
        configuration.title?.iOSFontInfo?.fontName);
    expect(titleJson["iOSFontInfo"]["systemFontStyle"],
        configuration.title?.iOSFontInfo?.systemFontStyle?.name);
    expect(titleJson["iOSFontInfo"]["systemFontWeight"],
        configuration.title?.iOSFontInfo?.systemFontWeight?.name);
    expect(titleJson["androidFontInfo"]["isCustom"],
        configuration.title?.androidFontInfo?.isCustom);
    expect(titleJson["androidFontInfo"]["typefaceName"],
        configuration.title?.androidFontInfo?.typefaceName);
    expect(titleJson["gradientDrawable"]["orientation"],
        configuration.title?.gradientDrawable?.orientation?.rawName);
    expect(titleJson["gradientDrawable"]["colors"],
        configuration.title?.gradientDrawable?.colors);
    expect(json["titlePosition"], configuration.titlePosition?.name);
    expect(json["contentPadding"] is Map<String, dynamic>, true);
    final titlePaddingJson = json["titlePadding"] as Map<String, dynamic>;
    expect(titlePaddingJson["top"], configuration.titlePadding?.top);
    expect(titlePaddingJson["right"], configuration.titlePadding?.right);
    expect(titlePaddingJson["bottom"], configuration.titlePadding?.bottom);
    expect(titlePaddingJson["left"], configuration.titlePadding?.left);
    expect(json["playIcon"] is Map<String, dynamic>, true);
    final playIconJson = json["playIcon"] as Map<String, dynamic>;
    expect(playIconJson["hidden"], configuration.playIcon?.hidden);
    expect(playIconJson["iconWidth"], configuration.playIcon?.iconWidth);
    expect(json["contentPadding"] is Map<String, dynamic>, true);
    final contentPaddingJson = json["contentPadding"] as Map<String, dynamic>;
    expect(contentPaddingJson["top"], configuration.contentPadding?.top);
    expect(contentPaddingJson["right"], configuration.contentPadding?.right);
    expect(contentPaddingJson["bottom"], configuration.contentPadding?.bottom);
    expect(contentPaddingJson["left"], configuration.contentPadding?.left);
    expect(json["showAdBadge"], configuration.showAdBadge);
    expect(json["aspectRatio"], configuration.aspectRatio);
    expect(json["itemSpacing"], configuration.itemSpacing);
    expect(json["enableAutoplay"], configuration.enableAutoplay);
    expect(json["gridColumns"], configuration.gridColumns);
  });
}
